@@ -12,14 +12,20 @@ check_class <- function(argument, target, arg_name){
 
   if( !is.null(argument) ){
 
-    class_eval <- class(argument)[1]
+    # class_eval <- class(argument)[1]
+    class_eval <- class(argument) # para compatibilizar con zero_sum
 
     guess <- match(x = class_eval, table = target)
-    is_na <- sum(guess) # to get NA value
+    #is_na <- sum(guess) # to get NA value
+    zero_sum <- sum(guess, na.rm = TRUE) # this new option relax de validation
+                                         # and ask for just for some coincidence.
 
-    if( is.na(is_na) ){
+
+    if( zero_sum == 0 ){
       error_message <-
-        paste0('Oops...please check for ', arg_name, ' argument. Allowed classes are: ', paste(target, collapse = ', '), '.')
+        paste0('Oops...please check for ', arg_name,
+               ' argument. Allowed classes are: ',
+               paste(target, collapse = ', '), '.')
 
       stop( error_message, call. = FALSE )
     }
@@ -30,3 +36,4 @@ check_class <- function(argument, target, arg_name){
 
 
 }
+
